#!/bin/sh -e

BLUEZ_LIBS="libs"
BLUEZ_UTILS="utils"
BLUEZ_HCIDUMP="hcidump"

DIR_SRC="${PWD}"
DIR_OBJ="${PWD}/obj"
DIR_INS="${PWD}/ins"

CFG_BUILD="i686-linux"
CFG_HOST="i686-linux"
CFG_TARGET="i686-linux"
TNAME="Intel 80386"
STRIP="strip"

#export CFLAGS="-O0"
#export CPPFLAGS="-DSDP_DEBUG=1"


# $1 = src/obj path
# $2 = description
# $3 = extra configure options
do_build()
{
  mkdir -p "${DIR_OBJ}/$1"
  cd "${DIR_OBJ}/$1"

  echo "***** Configuring $2..."
  "${DIR_SRC}/$1/configure"	\
    --build="${CFG_BUILD}"	\
    --host="${CFG_HOST}"	\
    --target="${CFG_TARGET}"	\
    --prefix=""			\
    --with-bluez="${DIR_INS}"	\
    $3

  echo "***** Building $2..."
  make

  echo "***** Installing $2..."
  make install DESTDIR="${DIR_INS}"
}


do_build "${BLUEZ_LIBS}"    "BlueZ libraries"
do_build "${BLUEZ_UTILS}"   "BlueZ utilities"     --enable-test
do_build "${BLUEZ_HCIDUMP}" "BlueZ HCI dump tool"


echo "***** Stripping all BlueZ binaries..."
find "${DIR_INS}" -type f | xargs file | grep "${TNAME}, .*, not stripped" | cut -d: -f1 | xargs -r ${STRIP}


echo "***** Results can be found in ${DIR_INS}."

# EOF
